Module: Google::Apis::OsconfigV2

Defined in:
lib/google/apis/osconfig_v2.rb,
lib/google/apis/osconfig_v2/classes.rb,
lib/google/apis/osconfig_v2/service.rb,
lib/google/apis/osconfig_v2/gem_version.rb,
lib/google/apis/osconfig_v2/representations.rb

Overview

OS Config API

OS management tools that can be used for patch management, patch compliance, and configuration management on VM instances.

Defined Under Namespace

Classes: CancelOperationRequest, Empty, FixedOrPercent, GoogleCloudOsconfigCommonV1OperationMetadata, GoogleCloudOsconfigCommonV1alphaOperationMetadata, GoogleCloudOsconfigCommonV1mainOperationMetadata, GoogleCloudOsconfigV1OsPolicyAssignmentOperationMetadata, GoogleCloudOsconfigV2ListPolicyOrchestratorsResponse, GoogleCloudOsconfigV2OperationMetadata, GoogleCloudOsconfigV2OrchestratedResource, GoogleCloudOsconfigV2OrchestrationScope, GoogleCloudOsconfigV2OrchestrationScopeLocationSelector, GoogleCloudOsconfigV2OrchestrationScopeResourceHierarchySelector, GoogleCloudOsconfigV2OrchestrationScopeSelector, GoogleCloudOsconfigV2PolicyOrchestrator, GoogleCloudOsconfigV2PolicyOrchestratorIterationState, GoogleCloudOsconfigV2PolicyOrchestratorOrchestrationState, GoogleCloudOsconfigV2betaOperationMetadata, ListOperationsResponse, MessageSet, OSConfigService, Operation, OsPolicy, OsPolicyAssignment, OsPolicyAssignmentInstanceFilter, OsPolicyAssignmentInstanceFilterInventory, OsPolicyAssignmentLabelSet, OsPolicyAssignmentOperationMetadata, OsPolicyAssignmentRollout, OsPolicyInventoryFilter, OsPolicyResource, OsPolicyResourceExecResource, OsPolicyResourceExecResourceExec, OsPolicyResourceFile, OsPolicyResourceFileGcs, OsPolicyResourceFileRemote, OsPolicyResourceFileResource, OsPolicyResourceGroup, OsPolicyResourcePackageResource, OsPolicyResourcePackageResourceApt, OsPolicyResourcePackageResourceDeb, OsPolicyResourcePackageResourceGooGet, OsPolicyResourcePackageResourceMsi, OsPolicyResourcePackageResourceRpm, OsPolicyResourcePackageResourceYum, OsPolicyResourcePackageResourceZypper, OsPolicyResourceRepositoryResource, OsPolicyResourceRepositoryResourceAptRepository, OsPolicyResourceRepositoryResourceGooRepository, OsPolicyResourceRepositoryResourceYumRepository, OsPolicyResourceRepositoryResourceZypperRepository, Status, StatusProto

Constant Summary collapse

GEM_VERSION =

Version of the google-apis-osconfig_v2 gem

"0.7.0"
GENERATOR_VERSION =

Version of the code generator used to generate this client

"0.18.0"
REVISION =

Revision of the discovery document this client was generated from

"20260325"
VERSION =

Version of the OS Config API this client connects to. This is NOT the gem version.

'V2'
AUTH_CLOUD_PLATFORM =

See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.

'https://www.googleapis.com/auth/cloud-platform'