Class: Google::Apis::OsconfigV2::GoogleCloudOsconfigCommonV1alphaOperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV2::GoogleCloudOsconfigCommonV1alphaOperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v2/classes.rb,
lib/google/apis/osconfig_v2/representations.rb,
lib/google/apis/osconfig_v2/representations.rb
Overview
Represents the metadata of a generic long-running operation.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#requested_cancellation ⇒ Boolean
(also: #requested_cancellation?)
Output only.
-
#status_message ⇒ String
Output only.
-
#target ⇒ String
Output only.
-
#verb ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudOsconfigCommonV1alphaOperationMetadata
constructor
A new instance of GoogleCloudOsconfigCommonV1alphaOperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudOsconfigCommonV1alphaOperationMetadata
Returns a new instance of GoogleCloudOsconfigCommonV1alphaOperationMetadata.
183 184 185 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 183 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Output only. API version used to start the operation.
Corresponds to the JSON property apiVersion
147 148 149 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 147 def api_version @api_version end |
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
152 153 154 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 152 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
157 158 159 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 157 def end_time @end_time end |
#requested_cancellation ⇒ Boolean Also known as: requested_cancellation?
Output only. Identifies whether the user has requested cancellation of the
operation. Operations that have successfully been cancelled have Operation.
error value with a google.rpc.Status.code of 1, corresponding to Code.
CANCELLED.
Corresponds to the JSON property requestedCancellation
165 166 167 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 165 def requested_cancellation @requested_cancellation end |
#status_message ⇒ String
Output only. Human-readable status of the operation, if any.
Corresponds to the JSON property statusMessage
171 172 173 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 171 def @status_message end |
#target ⇒ String
Output only. Server-defined resource path for the target of the operation.
Corresponds to the JSON property target
176 177 178 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 176 def target @target end |
#verb ⇒ String
Output only. Name of the verb executed by the operation.
Corresponds to the JSON property verb
181 182 183 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 181 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
188 189 190 191 192 193 194 195 196 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 188 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation) @status_message = args[:status_message] if args.key?(:status_message) @target = args[:target] if args.key?(:target) @verb = args[:verb] if args.key?(:verb) end |