Class: Google::Apis::OsconfigV2::GoogleCloudOsconfigV2OrchestratedResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v2/classes.rb,
lib/google/apis/osconfig_v2/representations.rb,
lib/google/apis/osconfig_v2/representations.rb

Overview

Represents a resource that is being orchestrated by the policy orchestrator.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudOsconfigV2OrchestratedResource

Returns a new instance of GoogleCloudOsconfigV2OrchestratedResource.



584
585
586
# File 'lib/google/apis/osconfig_v2/classes.rb', line 584

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Optional. ID of the resource to be used while generating set of affected resources. For UPSERT action the value is auto-generated during PolicyOrchestrator creation when not set. When the value is set it should following next restrictions: * Must contain only lowercase letters, numbers, and hyphens. * Must start with a letter. * Must be between 1-63 characters. * Must end with a number or a letter. * Must be unique within the project. For DELETE action, ID must be specified explicitly during PolicyOrchestrator creation. Corresponds to the JSON property id

Returns:

  • (String)


570
571
572
# File 'lib/google/apis/osconfig_v2/classes.rb', line 570

def id
  @id
end

#os_policy_assignment_v1_payloadGoogle::Apis::OsconfigV2::OsPolicyAssignment

OS policy assignment is an API resource that is used to apply a set of OS policies to a dynamically targeted group of Compute Engine VM instances. An OS policy is used to define the desired state configuration for a Compute Engine VM instance through a set of configuration resources that provide capabilities such as installing or removing software packages, or executing a script. For more information about the OS policy resource definitions and examples, see OS policy and OS policy assignment. Corresponds to the JSON property osPolicyAssignmentV1Payload



582
583
584
# File 'lib/google/apis/osconfig_v2/classes.rb', line 582

def os_policy_assignment_v1_payload
  @os_policy_assignment_v1_payload
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



589
590
591
592
# File 'lib/google/apis/osconfig_v2/classes.rb', line 589

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @os_policy_assignment_v1_payload = args[:os_policy_assignment_v1_payload] if args.key?(:os_policy_assignment_v1_payload)
end