Class: Google::Apis::OsconfigV2::GoogleCloudOsconfigV2OrchestrationScope

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v2/classes.rb,
lib/google/apis/osconfig_v2/representations.rb,
lib/google/apis/osconfig_v2/representations.rb

Overview

Defines a set of selectors which drive which resources are in scope of policy orchestration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudOsconfigV2OrchestrationScope

Returns a new instance of GoogleCloudOsconfigV2OrchestrationScope.



431
432
433
# File 'lib/google/apis/osconfig_v2/classes.rb', line 431

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#selectorsArray<Google::Apis::OsconfigV2::GoogleCloudOsconfigV2OrchestrationScopeSelector>

Optional. Selectors of the orchestration scope. There is a logical AND between each selector defined. When there is no explicit ResourceHierarchySelector selector specified, the scope is by default bounded to the parent of the policy orchestrator resource. Corresponds to the JSON property selectors



429
430
431
# File 'lib/google/apis/osconfig_v2/classes.rb', line 429

def selectors
  @selectors
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



436
437
438
# File 'lib/google/apis/osconfig_v2/classes.rb', line 436

def update!(**args)
  @selectors = args[:selectors] if args.key?(:selectors)
end