Class: Google::Apis::OsconfigV2::OsPolicyAssignment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v2/classes.rb,
lib/google/apis/osconfig_v2/representations.rb,
lib/google/apis/osconfig_v2/representations.rb

Overview

OS policy assignment is an API resource that is used to apply a set of OS policies to a dynamically targeted group of Compute Engine VM instances. An OS policy is used to define the desired state configuration for a Compute Engine VM instance through a set of configuration resources that provide capabilities such as installing or removing software packages, or executing a script. For more information about the OS policy resource definitions and examples, see OS policy and OS policy assignment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OsPolicyAssignment

Returns a new instance of OsPolicyAssignment.



992
993
994
# File 'lib/google/apis/osconfig_v2/classes.rb', line 992

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#baselineBoolean Also known as: baseline?

Output only. Indicates that this revision has been successfully rolled out in this zone and new VMs will be assigned OS policies from this revision. For a given OS policy assignment, there is only one revision with a value of true for this field. Corresponds to the JSON property baseline

Returns:

  • (Boolean)


917
918
919
# File 'lib/google/apis/osconfig_v2/classes.rb', line 917

def baseline
  @baseline
end

#deletedBoolean Also known as: deleted?

Output only. Indicates that this revision deletes the OS policy assignment. Corresponds to the JSON property deleted

Returns:

  • (Boolean)


923
924
925
# File 'lib/google/apis/osconfig_v2/classes.rb', line 923

def deleted
  @deleted
end

#descriptionString

OS policy assignment description. Length of the description is limited to 1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


930
931
932
# File 'lib/google/apis/osconfig_v2/classes.rb', line 930

def description
  @description
end

#etagString

The etag for this OS policy assignment. If this is provided on update, it must match the server's etag. Corresponds to the JSON property etag

Returns:

  • (String)


936
937
938
# File 'lib/google/apis/osconfig_v2/classes.rb', line 936

def etag
  @etag
end

#instance_filterGoogle::Apis::OsconfigV2::OsPolicyAssignmentInstanceFilter

Filters to select target VMs for an assignment. If more than one filter criteria is specified below, a VM will be selected if and only if it satisfies all of them. Corresponds to the JSON property instanceFilter



943
944
945
# File 'lib/google/apis/osconfig_v2/classes.rb', line 943

def instance_filter
  @instance_filter
end

#nameString

Resource name. Format: projects/project_number/locations/location/ osPolicyAssignments/os_policy_assignment_id`This field is ignored when you create an OS policy assignment. Corresponds to the JSON propertyname`

Returns:

  • (String)


950
951
952
# File 'lib/google/apis/osconfig_v2/classes.rb', line 950

def name
  @name
end

#os_policiesArray<Google::Apis::OsconfigV2::OsPolicy>

Required. List of OS policies to be applied to the VMs. Corresponds to the JSON property osPolicies



955
956
957
# File 'lib/google/apis/osconfig_v2/classes.rb', line 955

def os_policies
  @os_policies
end

#reconcilingBoolean Also known as: reconciling?

Output only. Indicates that reconciliation is in progress for the revision. This value is true when the rollout_state is one of: * IN_PROGRESS * CANCELLING Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


962
963
964
# File 'lib/google/apis/osconfig_v2/classes.rb', line 962

def reconciling
  @reconciling
end

#revision_create_timeString

Output only. The timestamp that the revision was created. Corresponds to the JSON property revisionCreateTime

Returns:

  • (String)


968
969
970
# File 'lib/google/apis/osconfig_v2/classes.rb', line 968

def revision_create_time
  @revision_create_time
end

#revision_idString

Output only. The assignment revision ID A new revision is committed whenever a rollout is triggered for a OS policy assignment Corresponds to the JSON property revisionId

Returns:

  • (String)


974
975
976
# File 'lib/google/apis/osconfig_v2/classes.rb', line 974

def revision_id
  @revision_id
end

#rolloutGoogle::Apis::OsconfigV2::OsPolicyAssignmentRollout

Message to configure the rollout at the zonal level for the OS policy assignment. Corresponds to the JSON property rollout



980
981
982
# File 'lib/google/apis/osconfig_v2/classes.rb', line 980

def rollout
  @rollout
end

#rollout_stateString

Output only. OS policy assignment rollout state Corresponds to the JSON property rolloutState

Returns:

  • (String)


985
986
987
# File 'lib/google/apis/osconfig_v2/classes.rb', line 985

def rollout_state
  @rollout_state
end

#uidString

Output only. Server generated unique id for the OS policy assignment resource. Corresponds to the JSON property uid

Returns:

  • (String)


990
991
992
# File 'lib/google/apis/osconfig_v2/classes.rb', line 990

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
# File 'lib/google/apis/osconfig_v2/classes.rb', line 997

def update!(**args)
  @baseline = args[:baseline] if args.key?(:baseline)
  @deleted = args[:deleted] if args.key?(:deleted)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @instance_filter = args[:instance_filter] if args.key?(:instance_filter)
  @name = args[:name] if args.key?(:name)
  @os_policies = args[:os_policies] if args.key?(:os_policies)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @revision_create_time = args[:revision_create_time] if args.key?(:revision_create_time)
  @revision_id = args[:revision_id] if args.key?(:revision_id)
  @rollout = args[:rollout] if args.key?(:rollout)
  @rollout_state = args[:rollout_state] if args.key?(:rollout_state)
  @uid = args[:uid] if args.key?(:uid)
end