Class: Google::Apis::OsconfigV2::OsPolicyAssignmentRollout
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV2::OsPolicyAssignmentRollout
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v2/classes.rb,
lib/google/apis/osconfig_v2/representations.rb,
lib/google/apis/osconfig_v2/representations.rb
Overview
Message to configure the rollout at the zonal level for the OS policy assignment.
Instance Attribute Summary collapse
-
#disruption_budget ⇒ Google::Apis::OsconfigV2::FixedOrPercent
Message encapsulating a value that can be either absolute ("fixed") or relative ("percent") to a value.
-
#min_wait_duration ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OsPolicyAssignmentRollout
constructor
A new instance of OsPolicyAssignmentRollout.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OsPolicyAssignmentRollout
Returns a new instance of OsPolicyAssignmentRollout.
1000 1001 1002 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1000 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disruption_budget ⇒ Google::Apis::OsconfigV2::FixedOrPercent
Message encapsulating a value that can be either absolute ("fixed") or
relative ("percent") to a value.
Corresponds to the JSON property disruptionBudget
990 991 992 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 990 def disruption_budget @disruption_budget end |
#min_wait_duration ⇒ String
Required. This determines the minimum duration of time to wait after the
configuration changes are applied through the current rollout. A VM continues
to count towards the disruption_budget at least until this duration of time
has passed after configuration changes are applied.
Corresponds to the JSON property minWaitDuration
998 999 1000 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 998 def min_wait_duration @min_wait_duration end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1005 1006 1007 1008 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1005 def update!(**args) @disruption_budget = args[:disruption_budget] if args.key?(:disruption_budget) @min_wait_duration = args[:min_wait_duration] if args.key?(:min_wait_duration) end |