Class: Google::Apis::OsconfigV2::OsPolicyResourceExecResourceExec
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV2::OsPolicyResourceExecResourceExec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v2/classes.rb,
lib/google/apis/osconfig_v2/representations.rb,
lib/google/apis/osconfig_v2/representations.rb
Overview
A file or script to execute.
Instance Attribute Summary collapse
-
#args ⇒ Array<String>
Optional arguments to pass to the source during execution.
-
#file ⇒ Google::Apis::OsconfigV2::OsPolicyResourceFile
A remote or local file.
-
#interpreter ⇒ String
Required.
-
#output_file_path ⇒ String
Only recorded for enforce Exec.
-
#script ⇒ String
An inline script.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OsPolicyResourceExecResourceExec
constructor
A new instance of OsPolicyResourceExecResourceExec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OsPolicyResourceExecResourceExec
Returns a new instance of OsPolicyResourceExecResourceExec.
1357 1358 1359 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1357 def initialize(**args) update!(**args) end |
Instance Attribute Details
#args ⇒ Array<String>
Optional arguments to pass to the source during execution.
Corresponds to the JSON property args
1332 1333 1334 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1332 def args @args end |
#file ⇒ Google::Apis::OsconfigV2::OsPolicyResourceFile
A remote or local file.
Corresponds to the JSON property file
1337 1338 1339 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1337 def file @file end |
#interpreter ⇒ String
Required. The script interpreter to use.
Corresponds to the JSON property interpreter
1342 1343 1344 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1342 def interpreter @interpreter end |
#output_file_path ⇒ String
Only recorded for enforce Exec. Path to an output file (that is created by
this Exec) whose content will be recorded in OSPolicyResourceCompliance after
a successful run. Absence or failure to read this file will result in this
ExecResource being non-compliant. Output file size is limited to 500K bytes.
Corresponds to the JSON property outputFilePath
1350 1351 1352 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1350 def output_file_path @output_file_path end |
#script ⇒ String
An inline script. The size of the script is limited to 32KiB.
Corresponds to the JSON property script
1355 1356 1357 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1355 def script @script end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1362 1363 1364 1365 1366 1367 1368 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1362 def update!(**args) @args = args[:args] if args.key?(:args) @file = args[:file] if args.key?(:file) @interpreter = args[:interpreter] if args.key?(:interpreter) @output_file_path = args[:output_file_path] if args.key?(:output_file_path) @script = args[:script] if args.key?(:script) end |