Class: Google::Apis::OsconfigV2::OsPolicyResourceFile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v2/classes.rb,
lib/google/apis/osconfig_v2/representations.rb,
lib/google/apis/osconfig_v2/representations.rb

Overview

A remote or local file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OsPolicyResourceFile

Returns a new instance of OsPolicyResourceFile.



1398
1399
1400
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1398

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_insecureBoolean Also known as: allow_insecure?

Defaults to false. When false, files are subject to validations based on the file type: Remote: A checksum must be specified. Cloud Storage: An object generation number must be specified. Corresponds to the JSON property allowInsecure

Returns:

  • (Boolean)


1380
1381
1382
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1380

def allow_insecure
  @allow_insecure
end

#gcsGoogle::Apis::OsconfigV2::OsPolicyResourceFileGcs

Specifies a file available as a Cloud Storage Object. Corresponds to the JSON property gcs



1386
1387
1388
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1386

def gcs
  @gcs
end

#local_pathString

A local path within the VM to use. Corresponds to the JSON property localPath

Returns:

  • (String)


1391
1392
1393
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1391

def local_path
  @local_path
end

#remoteGoogle::Apis::OsconfigV2::OsPolicyResourceFileRemote

Specifies a file available via some URI. Corresponds to the JSON property remote



1396
1397
1398
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1396

def remote
  @remote
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1403
1404
1405
1406
1407
1408
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1403

def update!(**args)
  @allow_insecure = args[:allow_insecure] if args.key?(:allow_insecure)
  @gcs = args[:gcs] if args.key?(:gcs)
  @local_path = args[:local_path] if args.key?(:local_path)
  @remote = args[:remote] if args.key?(:remote)
end