Class: Google::Apis::OsconfigV2::OsPolicyResourceGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v2/classes.rb,
lib/google/apis/osconfig_v2/representations.rb,
lib/google/apis/osconfig_v2/representations.rb

Overview

Resource groups provide a mechanism to group OS policy resources. Resource groups enable OS policy authors to create a single OS policy to be applied to VMs running different operating Systems. When the OS policy is applied to a target VM, the appropriate resource group within the OS policy is selected based on the OSFilter specified within the resource group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OsPolicyResourceGroup

Returns a new instance of OsPolicyResourceGroup.



1543
1544
1545
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1543

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inventory_filtersArray<Google::Apis::OsconfigV2::OsPolicyInventoryFilter>

List of inventory filters for the resource group. The resources in this resource group are applied to the target VM if it satisfies at least one of the following inventory filters. For example, to apply this resource group to VMs running either RHEL or CentOS operating systems, specify 2 items for the list with following values: inventory_filters[0].os_short_name='rhel' and inventory_filters[1].os_short_name='centos' If the list is empty, this resource group will be applied to the target VM unconditionally. Corresponds to the JSON property inventoryFilters



1535
1536
1537
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1535

def inventory_filters
  @inventory_filters
end

#resourcesArray<Google::Apis::OsconfigV2::OsPolicyResource>

Required. List of resources configured for this resource group. The resources are executed in the exact order specified here. Corresponds to the JSON property resources



1541
1542
1543
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1541

def resources
  @resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1548
1549
1550
1551
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1548

def update!(**args)
  @inventory_filters = args[:inventory_filters] if args.key?(:inventory_filters)
  @resources = args[:resources] if args.key?(:resources)
end