Class: Google::Apis::OsconfigV2::OsPolicyResourceRepositoryResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v2/classes.rb,
lib/google/apis/osconfig_v2/representations.rb,
lib/google/apis/osconfig_v2/representations.rb

Overview

A resource that manages a package repository.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OsPolicyResourceRepositoryResource

Returns a new instance of OsPolicyResourceRepositoryResource.



1810
1811
1812
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1810

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aptGoogle::Apis::OsconfigV2::OsPolicyResourceRepositoryResourceAptRepository

Represents a single apt package repository. These will be added to a repo file that will be managed at /etc/apt/sources.list.d/google_osconfig.list. Corresponds to the JSON property apt



1790
1791
1792
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1790

def apt
  @apt
end

#gooGoogle::Apis::OsconfigV2::OsPolicyResourceRepositoryResourceGooRepository

Represents a Goo package repository. These are added to a repo file that is managed at C:/ProgramData/GooGet/repos/google_osconfig.repo. Corresponds to the JSON property goo



1796
1797
1798
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1796

def goo
  @goo
end

#yumGoogle::Apis::OsconfigV2::OsPolicyResourceRepositoryResourceYumRepository

Represents a single yum package repository. These are added to a repo file that is managed at /etc/yum.repos.d/google_osconfig.repo. Corresponds to the JSON property yum



1802
1803
1804
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1802

def yum
  @yum
end

#zypperGoogle::Apis::OsconfigV2::OsPolicyResourceRepositoryResourceZypperRepository

Represents a single zypper package repository. These are added to a repo file that is managed at /etc/zypp/repos.d/google_osconfig.repo. Corresponds to the JSON property zypper



1808
1809
1810
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1808

def zypper
  @zypper
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1815
1816
1817
1818
1819
1820
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1815

def update!(**args)
  @apt = args[:apt] if args.key?(:apt)
  @goo = args[:goo] if args.key?(:goo)
  @yum = args[:yum] if args.key?(:yum)
  @zypper = args[:zypper] if args.key?(:zypper)
end