Class: Google::Apis::OsconfigV2::OsPolicyResourceRepositoryResourceYumRepository

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v2/classes.rb,
lib/google/apis/osconfig_v2/representations.rb,
lib/google/apis/osconfig_v2/representations.rb

Overview

Represents a single yum package repository. These are added to a repo file that is managed at /etc/yum.repos.d/google_osconfig.repo.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OsPolicyResourceRepositoryResourceYumRepository

Returns a new instance of OsPolicyResourceRepositoryResourceYumRepository.



1748
1749
1750
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1748

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_urlString

Required. The location of the repository directory. Corresponds to the JSON property baseUrl

Returns:

  • (String)


1728
1729
1730
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1728

def base_url
  @base_url
end

#display_nameString

The display name of the repository. Corresponds to the JSON property displayName

Returns:

  • (String)


1733
1734
1735
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1733

def display_name
  @display_name
end

#gpg_keysArray<String>

URIs of GPG keys. Corresponds to the JSON property gpgKeys

Returns:

  • (Array<String>)


1738
1739
1740
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1738

def gpg_keys
  @gpg_keys
end

#idString

Required. A one word, unique name for this repository. This is the repo id in the yum config file and also the display_name if display_name is omitted. This id is also used as the unique identifier when checking for resource conflicts. Corresponds to the JSON property id

Returns:

  • (String)


1746
1747
1748
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1746

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1753
1754
1755
1756
1757
1758
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1753

def update!(**args)
  @base_url = args[:base_url] if args.key?(:base_url)
  @display_name = args[:display_name] if args.key?(:display_name)
  @gpg_keys = args[:gpg_keys] if args.key?(:gpg_keys)
  @id = args[:id] if args.key?(:id)
end