Class: Google::Apis::OsconfigV2::StatusProto

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v2/classes.rb,
lib/google/apis/osconfig_v2/representations.rb,
lib/google/apis/osconfig_v2/representations.rb

Overview

Wire-format for a Status object

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StatusProto

Returns a new instance of StatusProto.



1947
1948
1949
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1947

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#canonical_codeFixnum

copybara:strip_begin(b/383363683) copybara:strip_end_and_replace optional int32 canonical_code = 6; Corresponds to the JSON property canonicalCode

Returns:

  • (Fixnum)


1911
1912
1913
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1911

def canonical_code
  @canonical_code
end

#codeFixnum

Numeric code drawn from the space specified below. Often, this is the canonical error space, and code is drawn from google3/util/task/codes.proto copybara:strip_begin(b/383363683) copybara:strip_end_and_replace optional int32 code = 1; Corresponds to the JSON property code

Returns:

  • (Fixnum)


1919
1920
1921
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1919

def code
  @code
end

#messageString

Detail message copybara:strip_begin(b/383363683) copybara: strip_end_and_replace optional string message = 3; Corresponds to the JSON property message

Returns:

  • (String)


1925
1926
1927
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1925

def message
  @message
end

#message_setGoogle::Apis::OsconfigV2::MessageSet

This is proto2's version of MessageSet. DEPRECATED: DO NOT USE FOR NEW FIELDS. If you are using editions or proto2, please make your own extendable messages for your use case. If you are using proto3, please use Any instead. MessageSet was the implementation of extensions for proto1. When proto2 was introduced, extensions were implemented as a first-class feature. This schema for MessageSet was meant to be a "bridge" solution to migrate MessageSet- bearing messages from proto1 to proto2. This schema has been open-sourced only to facilitate the migration of Google products with MessageSet-bearing messages to open-source environments. Corresponds to the JSON property messageSet



1938
1939
1940
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1938

def message_set
  @message_set
end

#spaceString

copybara:strip_begin(b/383363683) Space to which this status belongs copybara: strip_end_and_replace optional string space = 2; // Space to which this status belongs Corresponds to the JSON property space

Returns:

  • (String)


1945
1946
1947
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1945

def space
  @space
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1952
1953
1954
1955
1956
1957
1958
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1952

def update!(**args)
  @canonical_code = args[:canonical_code] if args.key?(:canonical_code)
  @code = args[:code] if args.key?(:code)
  @message = args[:message] if args.key?(:message)
  @message_set = args[:message_set] if args.key?(:message_set)
  @space = args[:space] if args.key?(:space)
end