Class: Google::Apis::OsconfigV2::GoogleCloudOsconfigV2PolicyOrchestratorIterationState
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV2::GoogleCloudOsconfigV2PolicyOrchestratorIterationState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v2/classes.rb,
lib/google/apis/osconfig_v2/representations.rb,
lib/google/apis/osconfig_v2/representations.rb
Overview
Describes the state of a single iteration of the orchestrator.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::OsconfigV2::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#failed_actions ⇒ Fixnum
Output only.
-
#finish_time ⇒ String
Output only.
-
#iteration_id ⇒ String
Output only.
-
#performed_actions ⇒ Fixnum
Output only.
-
#progress ⇒ Float
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudOsconfigV2PolicyOrchestratorIterationState
constructor
A new instance of GoogleCloudOsconfigV2PolicyOrchestratorIterationState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudOsconfigV2PolicyOrchestratorIterationState
Returns a new instance of GoogleCloudOsconfigV2PolicyOrchestratorIterationState.
423 424 425 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 423 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::OsconfigV2::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
385 386 387 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 385 def error @error end |
#failed_actions ⇒ Fixnum
Output only. Number of orchestration actions which failed so far. For more
details, query the Cloud Logs.
Corresponds to the JSON property failedActions
391 392 393 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 391 def failed_actions @failed_actions end |
#finish_time ⇒ String
Output only. Finish time of the wave iteration.
Corresponds to the JSON property finishTime
396 397 398 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 396 def finish_time @finish_time end |
#iteration_id ⇒ String
Output only. Unique identifier of the iteration.
Corresponds to the JSON property iterationId
401 402 403 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 401 def iteration_id @iteration_id end |
#performed_actions ⇒ Fixnum
Output only. Overall number of actions done by the orchestrator so far.
Corresponds to the JSON property performedActions
406 407 408 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 406 def performed_actions @performed_actions end |
#progress ⇒ Float
Output only. An estimated percentage of the progress. Number between 0 and 100.
Corresponds to the JSON property progress
411 412 413 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 411 def progress @progress end |
#start_time ⇒ String
Output only. Start time of the wave iteration.
Corresponds to the JSON property startTime
416 417 418 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 416 def start_time @start_time end |
#state ⇒ String
Output only. State of the iteration.
Corresponds to the JSON property state
421 422 423 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 421 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
428 429 430 431 432 433 434 435 436 437 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 428 def update!(**args) @error = args[:error] if args.key?(:error) @failed_actions = args[:failed_actions] if args.key?(:failed_actions) @finish_time = args[:finish_time] if args.key?(:finish_time) @iteration_id = args[:iteration_id] if args.key?(:iteration_id) @performed_actions = args[:performed_actions] if args.key?(:performed_actions) @progress = args[:progress] if args.key?(:progress) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) end |