Class: Google::Apis::OsconfigV2::GoogleCloudOsconfigV2PolicyOrchestratorOrchestrationState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v2/classes.rb,
lib/google/apis/osconfig_v2/representations.rb,
lib/google/apis/osconfig_v2/representations.rb

Overview

Describes the state of the orchestration process.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudOsconfigV2PolicyOrchestratorOrchestrationState

Returns a new instance of GoogleCloudOsconfigV2PolicyOrchestratorOrchestrationState.



454
455
456
# File 'lib/google/apis/osconfig_v2/classes.rb', line 454

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_iteration_stateGoogle::Apis::OsconfigV2::GoogleCloudOsconfigV2PolicyOrchestratorIterationState

Describes the state of a single iteration of the orchestrator. Corresponds to the JSON property currentIterationState



447
448
449
# File 'lib/google/apis/osconfig_v2/classes.rb', line 447

def current_iteration_state
  @current_iteration_state
end

#previous_iteration_stateGoogle::Apis::OsconfigV2::GoogleCloudOsconfigV2PolicyOrchestratorIterationState

Describes the state of a single iteration of the orchestrator. Corresponds to the JSON property previousIterationState



452
453
454
# File 'lib/google/apis/osconfig_v2/classes.rb', line 452

def previous_iteration_state
  @previous_iteration_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



459
460
461
462
# File 'lib/google/apis/osconfig_v2/classes.rb', line 459

def update!(**args)
  @current_iteration_state = args[:current_iteration_state] if args.key?(:current_iteration_state)
  @previous_iteration_state = args[:previous_iteration_state] if args.key?(:previous_iteration_state)
end