Class: Google::Apis::OsconfigV2::OSConfigService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::OsconfigV2::OSConfigService
- Defined in:
- lib/google/apis/osconfig_v2/service.rb
Overview
OS Config API
OS management tools that can be used for patch management, patch compliance, and configuration management on VM instances.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://osconfig.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_folder_location_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Empty
Starts asynchronous cancellation on a long-running operation.
-
#cancel_organization_location_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Empty
Starts asynchronous cancellation on a long-running operation.
-
#cancel_project_location_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_folder_location_global_policy_orchestrator(parent, google_cloud_osconfig_v2__policy_orchestrator_object = nil, policy_orchestrator_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Operation
Creates a new policy orchestrator under the given folder resource.
-
#create_organization_location_global_policy_orchestrator(parent, google_cloud_osconfig_v2__policy_orchestrator_object = nil, policy_orchestrator_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Operation
Creates a new policy orchestrator under the given organizations resource.
-
#create_project_location_global_policy_orchestrator(parent, google_cloud_osconfig_v2__policy_orchestrator_object = nil, policy_orchestrator_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Operation
Creates a new policy orchestrator under the given project resource.
-
#delete_folder_location_global_policy_orchestrator(name, etag: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Operation
Deletes an existing policy orchestrator resource, parented by a folder.
-
#delete_folder_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Empty
Deletes a long-running operation.
-
#delete_organization_location_global_policy_orchestrator(name, etag: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Operation
Deletes an existing policy orchestrator resource, parented by an organization.
-
#delete_organization_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Empty
Deletes a long-running operation.
-
#delete_project_location_global_policy_orchestrator(name, etag: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Operation
Deletes an existing policy orchestrator resource, parented by a project.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Empty
Deletes a long-running operation.
-
#get_folder_location_global_policy_orchestrator(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::GoogleCloudOsconfigV2PolicyOrchestrator
Retrieves an existing policy orchestrator, parented by a folder.
-
#get_folder_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Operation
Gets the latest state of a long-running operation.
-
#get_organization_location_global_policy_orchestrator(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::GoogleCloudOsconfigV2PolicyOrchestrator
Retrieves an existing policy orchestrator, parented by an organization.
-
#get_organization_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_global_policy_orchestrator(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::GoogleCloudOsconfigV2PolicyOrchestrator
Retrieves an existing policy orchestrator, parented by a project.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Operation
Gets the latest state of a long-running operation.
-
#initialize ⇒ OSConfigService
constructor
A new instance of OSConfigService.
-
#list_folder_location_global_policy_orchestrators(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::GoogleCloudOsconfigV2ListPolicyOrchestratorsResponse
Lists the policy orchestrators under the given parent folder resource.
-
#list_folder_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_organization_location_global_policy_orchestrators(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::GoogleCloudOsconfigV2ListPolicyOrchestratorsResponse
Lists the policy orchestrators under the given parent organization resource.
-
#list_organization_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_global_policy_orchestrators(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::GoogleCloudOsconfigV2ListPolicyOrchestratorsResponse
Lists the policy orchestrators under the given parent project resource.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#patch_folder_location_global_policy_orchestrator(name, google_cloud_osconfig_v2__policy_orchestrator_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Operation
Updates an existing policy orchestrator, parented by a folder.
-
#patch_organization_location_global_policy_orchestrator(name, google_cloud_osconfig_v2__policy_orchestrator_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Operation
Updates an existing policy orchestrator, parented by an organization.
-
#patch_project_location_global_policy_orchestrator(name, google_cloud_osconfig_v2__policy_orchestrator_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Operation
Updates an existing policy orchestrator, parented by a project.
Constructor Details
#initialize ⇒ OSConfigService
Returns a new instance of OSConfigService.
48 49 50 51 52 53 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-osconfig_v2', client_version: Google::Apis::OsconfigV2::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#cancel_folder_location_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 311 def cancel_folder_location_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:cancel', ) command.request_representation = Google::Apis::OsconfigV2::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::OsconfigV2::Empty::Representation command.response_class = Google::Apis::OsconfigV2::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#cancel_organization_location_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
692 693 694 695 696 697 698 699 700 701 702 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 692 def cancel_organization_location_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:cancel', ) command.request_representation = Google::Apis::OsconfigV2::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::OsconfigV2::Empty::Representation command.response_class = Google::Apis::OsconfigV2::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#cancel_project_location_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 1073 def cancel_project_location_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:cancel', ) command.request_representation = Google::Apis::OsconfigV2::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::OsconfigV2::Empty::Representation command.response_class = Google::Apis::OsconfigV2::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_folder_location_global_policy_orchestrator(parent, google_cloud_osconfig_v2__policy_orchestrator_object = nil, policy_orchestrator_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Operation
Creates a new policy orchestrator under the given folder resource. name
field of the given orchestrator are ignored and instead replaced by a product
of parent and policy_orchestrator_id. Orchestrator state field might be
only set to ACTIVE, STOPPED or omitted (in which case, the created
resource will be in ACTIVE state anyway).
98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 98 def create_folder_location_global_policy_orchestrator(parent, google_cloud_osconfig_v2__policy_orchestrator_object = nil, policy_orchestrator_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+parent}/policyOrchestrators', ) command.request_representation = Google::Apis::OsconfigV2::GoogleCloudOsconfigV2PolicyOrchestrator::Representation command.request_object = google_cloud_osconfig_v2__policy_orchestrator_object command.response_representation = Google::Apis::OsconfigV2::Operation::Representation command.response_class = Google::Apis::OsconfigV2::Operation command.params['parent'] = parent unless parent.nil? command.query['policyOrchestratorId'] = policy_orchestrator_id unless policy_orchestrator_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_organization_location_global_policy_orchestrator(parent, google_cloud_osconfig_v2__policy_orchestrator_object = nil, policy_orchestrator_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Operation
Creates a new policy orchestrator under the given organizations resource.
name field of the given orchestrator are ignored and instead replaced by a
product of parent and policy_orchestrator_id. Orchestrator state field
might be only set to ACTIVE, STOPPED or omitted (in which case, the
created resource will be in ACTIVE state anyway).
479 480 481 482 483 484 485 486 487 488 489 490 491 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 479 def create_organization_location_global_policy_orchestrator(parent, google_cloud_osconfig_v2__policy_orchestrator_object = nil, policy_orchestrator_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+parent}/policyOrchestrators', ) command.request_representation = Google::Apis::OsconfigV2::GoogleCloudOsconfigV2PolicyOrchestrator::Representation command.request_object = google_cloud_osconfig_v2__policy_orchestrator_object command.response_representation = Google::Apis::OsconfigV2::Operation::Representation command.response_class = Google::Apis::OsconfigV2::Operation command.params['parent'] = parent unless parent.nil? command.query['policyOrchestratorId'] = policy_orchestrator_id unless policy_orchestrator_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_global_policy_orchestrator(parent, google_cloud_osconfig_v2__policy_orchestrator_object = nil, policy_orchestrator_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Operation
Creates a new policy orchestrator under the given project resource. name
field of the given orchestrator are ignored and instead replaced by a product
of parent and policy_orchestrator_id. Orchestrator state field might be
only set to ACTIVE, STOPPED or omitted (in which case, the created
resource will be in ACTIVE state anyway).
860 861 862 863 864 865 866 867 868 869 870 871 872 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 860 def create_project_location_global_policy_orchestrator(parent, google_cloud_osconfig_v2__policy_orchestrator_object = nil, policy_orchestrator_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+parent}/policyOrchestrators', ) command.request_representation = Google::Apis::OsconfigV2::GoogleCloudOsconfigV2PolicyOrchestrator::Representation command.request_object = google_cloud_osconfig_v2__policy_orchestrator_object command.response_representation = Google::Apis::OsconfigV2::Operation::Representation command.response_class = Google::Apis::OsconfigV2::Operation command.params['parent'] = parent unless parent.nil? command.query['policyOrchestratorId'] = policy_orchestrator_id unless policy_orchestrator_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_folder_location_global_policy_orchestrator(name, etag: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Operation
Deletes an existing policy orchestrator resource, parented by a folder.
147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 147 def delete_folder_location_global_policy_orchestrator(name, etag: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2/{+name}', ) command.response_representation = Google::Apis::OsconfigV2::Operation::Representation command.response_class = Google::Apis::OsconfigV2::Operation command.params['name'] = name unless name.nil? command.query['etag'] = etag unless etag.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_folder_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
346 347 348 349 350 351 352 353 354 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 346 def delete_folder_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2/{+name}', ) command.response_representation = Google::Apis::OsconfigV2::Empty::Representation command.response_class = Google::Apis::OsconfigV2::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_organization_location_global_policy_orchestrator(name, etag: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Operation
Deletes an existing policy orchestrator resource, parented by an organization.
528 529 530 531 532 533 534 535 536 537 538 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 528 def delete_organization_location_global_policy_orchestrator(name, etag: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2/{+name}', ) command.response_representation = Google::Apis::OsconfigV2::Operation::Representation command.response_class = Google::Apis::OsconfigV2::Operation command.params['name'] = name unless name.nil? command.query['etag'] = etag unless etag.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_organization_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
727 728 729 730 731 732 733 734 735 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 727 def delete_organization_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2/{+name}', ) command.response_representation = Google::Apis::OsconfigV2::Empty::Representation command.response_class = Google::Apis::OsconfigV2::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_global_policy_orchestrator(name, etag: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Operation
Deletes an existing policy orchestrator resource, parented by a project.
909 910 911 912 913 914 915 916 917 918 919 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 909 def delete_project_location_global_policy_orchestrator(name, etag: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2/{+name}', ) command.response_representation = Google::Apis::OsconfigV2::Operation::Representation command.response_class = Google::Apis::OsconfigV2::Operation command.params['name'] = name unless name.nil? command.query['etag'] = etag unless etag.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 1108 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2/{+name}', ) command.response_representation = Google::Apis::OsconfigV2::Empty::Representation command.response_class = Google::Apis::OsconfigV2::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_folder_location_global_policy_orchestrator(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::GoogleCloudOsconfigV2PolicyOrchestrator
Retrieves an existing policy orchestrator, parented by a folder.
179 180 181 182 183 184 185 186 187 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 179 def get_folder_location_global_policy_orchestrator(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::OsconfigV2::GoogleCloudOsconfigV2PolicyOrchestrator::Representation command.response_class = Google::Apis::OsconfigV2::GoogleCloudOsconfigV2PolicyOrchestrator command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_folder_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
377 378 379 380 381 382 383 384 385 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 377 def get_folder_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::OsconfigV2::Operation::Representation command.response_class = Google::Apis::OsconfigV2::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_global_policy_orchestrator(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::GoogleCloudOsconfigV2PolicyOrchestrator
Retrieves an existing policy orchestrator, parented by an organization.
560 561 562 563 564 565 566 567 568 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 560 def get_organization_location_global_policy_orchestrator(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::OsconfigV2::GoogleCloudOsconfigV2PolicyOrchestrator::Representation command.response_class = Google::Apis::OsconfigV2::GoogleCloudOsconfigV2PolicyOrchestrator command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
758 759 760 761 762 763 764 765 766 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 758 def get_organization_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::OsconfigV2::Operation::Representation command.response_class = Google::Apis::OsconfigV2::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_global_policy_orchestrator(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::GoogleCloudOsconfigV2PolicyOrchestrator
Retrieves an existing policy orchestrator, parented by a project.
941 942 943 944 945 946 947 948 949 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 941 def get_project_location_global_policy_orchestrator(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::OsconfigV2::GoogleCloudOsconfigV2PolicyOrchestrator::Representation command.response_class = Google::Apis::OsconfigV2::GoogleCloudOsconfigV2PolicyOrchestrator command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
1139 1140 1141 1142 1143 1144 1145 1146 1147 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 1139 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::OsconfigV2::Operation::Representation command.response_class = Google::Apis::OsconfigV2::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_folder_location_global_policy_orchestrators(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::GoogleCloudOsconfigV2ListPolicyOrchestratorsResponse
Lists the policy orchestrators under the given parent folder resource.
218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 218 def list_folder_location_global_policy_orchestrators(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+parent}/policyOrchestrators', ) command.response_representation = Google::Apis::OsconfigV2::GoogleCloudOsconfigV2ListPolicyOrchestratorsResponse::Representation command.response_class = Google::Apis::OsconfigV2::GoogleCloudOsconfigV2ListPolicyOrchestratorsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_folder_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 422 def list_folder_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}/operations', ) command.response_representation = Google::Apis::OsconfigV2::ListOperationsResponse::Representation command.response_class = Google::Apis::OsconfigV2::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_global_policy_orchestrators(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::GoogleCloudOsconfigV2ListPolicyOrchestratorsResponse
Lists the policy orchestrators under the given parent organization resource.
599 600 601 602 603 604 605 606 607 608 609 610 611 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 599 def list_organization_location_global_policy_orchestrators(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+parent}/policyOrchestrators', ) command.response_representation = Google::Apis::OsconfigV2::GoogleCloudOsconfigV2ListPolicyOrchestratorsResponse::Representation command.response_class = Google::Apis::OsconfigV2::GoogleCloudOsconfigV2ListPolicyOrchestratorsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
803 804 805 806 807 808 809 810 811 812 813 814 815 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 803 def list_organization_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}/operations', ) command.response_representation = Google::Apis::OsconfigV2::ListOperationsResponse::Representation command.response_class = Google::Apis::OsconfigV2::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_global_policy_orchestrators(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::GoogleCloudOsconfigV2ListPolicyOrchestratorsResponse
Lists the policy orchestrators under the given parent project resource.
980 981 982 983 984 985 986 987 988 989 990 991 992 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 980 def list_project_location_global_policy_orchestrators(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+parent}/policyOrchestrators', ) command.response_representation = Google::Apis::OsconfigV2::GoogleCloudOsconfigV2ListPolicyOrchestratorsResponse::Representation command.response_class = Google::Apis::OsconfigV2::GoogleCloudOsconfigV2ListPolicyOrchestratorsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 1184 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}/operations', ) command.response_representation = Google::Apis::OsconfigV2::ListOperationsResponse::Representation command.response_class = Google::Apis::OsconfigV2::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_folder_location_global_policy_orchestrator(name, google_cloud_osconfig_v2__policy_orchestrator_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Operation
Updates an existing policy orchestrator, parented by a folder.
270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 270 def patch_folder_location_global_policy_orchestrator(name, google_cloud_osconfig_v2__policy_orchestrator_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v2/{+name}', ) command.request_representation = Google::Apis::OsconfigV2::GoogleCloudOsconfigV2PolicyOrchestrator::Representation command.request_object = google_cloud_osconfig_v2__policy_orchestrator_object command.response_representation = Google::Apis::OsconfigV2::Operation::Representation command.response_class = Google::Apis::OsconfigV2::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_organization_location_global_policy_orchestrator(name, google_cloud_osconfig_v2__policy_orchestrator_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Operation
Updates an existing policy orchestrator, parented by an organization.
651 652 653 654 655 656 657 658 659 660 661 662 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 651 def patch_organization_location_global_policy_orchestrator(name, google_cloud_osconfig_v2__policy_orchestrator_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v2/{+name}', ) command.request_representation = Google::Apis::OsconfigV2::GoogleCloudOsconfigV2PolicyOrchestrator::Representation command.request_object = google_cloud_osconfig_v2__policy_orchestrator_object command.response_representation = Google::Apis::OsconfigV2::Operation::Representation command.response_class = Google::Apis::OsconfigV2::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_global_policy_orchestrator(name, google_cloud_osconfig_v2__policy_orchestrator_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::OsconfigV2::Operation
Updates an existing policy orchestrator, parented by a project.
1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/google/apis/osconfig_v2/service.rb', line 1032 def patch_project_location_global_policy_orchestrator(name, google_cloud_osconfig_v2__policy_orchestrator_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v2/{+name}', ) command.request_representation = Google::Apis::OsconfigV2::GoogleCloudOsconfigV2PolicyOrchestrator::Representation command.request_object = google_cloud_osconfig_v2__policy_orchestrator_object command.response_representation = Google::Apis::OsconfigV2::Operation::Representation command.response_class = Google::Apis::OsconfigV2::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |