Class: Google::Apis::OsconfigV2::OsPolicy
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV2::OsPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v2/classes.rb,
lib/google/apis/osconfig_v2/representations.rb,
lib/google/apis/osconfig_v2/representations.rb
Overview
An OS policy defines the desired state configuration for a VM.
Instance Attribute Summary collapse
-
#allow_no_resource_group_match ⇒ Boolean
(also: #allow_no_resource_group_match?)
This flag determines the OS policy compliance status when none of the resource groups within the policy are applicable for a VM.
-
#description ⇒ String
Policy description.
-
#id ⇒ String
Required.
-
#mode ⇒ String
Required.
-
#resource_groups ⇒ Array<Google::Apis::OsconfigV2::OsPolicyResourceGroup>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OsPolicy
constructor
A new instance of OsPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OsPolicy
Returns a new instance of OsPolicy.
886 887 888 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 886 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_no_resource_group_match ⇒ Boolean Also known as: allow_no_resource_group_match?
This flag determines the OS policy compliance status when none of the resource
groups within the policy are applicable for a VM. Set this value to true if
the policy needs to be reported as compliant even if the policy has nothing to
validate or enforce.
Corresponds to the JSON property allowNoResourceGroupMatch
855 856 857 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 855 def allow_no_resource_group_match @allow_no_resource_group_match end |
#description ⇒ String
Policy description. Length of the description is limited to 1024 characters.
Corresponds to the JSON property description
861 862 863 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 861 def description @description end |
#id ⇒ String
Required. The id of the OS policy with the following restrictions: * Must
contain only lowercase letters, numbers, and hyphens. * Must start with a
letter. * Must be between 1-63 characters. * Must end with a number or a
letter. * Must be unique within the assignment.
Corresponds to the JSON property id
869 870 871 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 869 def id @id end |
#mode ⇒ String
Required. Policy mode
Corresponds to the JSON property mode
874 875 876 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 874 def mode @mode end |
#resource_groups ⇒ Array<Google::Apis::OsconfigV2::OsPolicyResourceGroup>
Required. List of resource groups for the policy. For a particular VM,
resource groups are evaluated in the order specified and the first resource
group that is applicable is selected and the rest are ignored. If none of the
resource groups are applicable for a VM, the VM is considered to be non-
compliant w.r.t this policy. This behavior can be toggled by the flag
allow_no_resource_group_match
Corresponds to the JSON property resourceGroups
884 885 886 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 884 def resource_groups @resource_groups end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
891 892 893 894 895 896 897 |
# File 'lib/google/apis/osconfig_v2/classes.rb', line 891 def update!(**args) @allow_no_resource_group_match = args[:allow_no_resource_group_match] if args.key?(:allow_no_resource_group_match) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @mode = args[:mode] if args.key?(:mode) @resource_groups = args[:resource_groups] if args.key?(:resource_groups) end |