Class: Google::Apis::OsconfigV2::OsPolicyResourceFileResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v2/classes.rb,
lib/google/apis/osconfig_v2/representations.rb,
lib/google/apis/osconfig_v2/representations.rb

Overview

A resource that manages the state of a file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OsPolicyResourceFileResource

Returns a new instance of OsPolicyResourceFileResource.



1504
1505
1506
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1504

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentString

A file with this content. The size of the content is limited to 32KiB. Corresponds to the JSON property content

Returns:

  • (String)


1475
1476
1477
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1475

def content
  @content
end

#fileGoogle::Apis::OsconfigV2::OsPolicyResourceFile

A remote or local file. Corresponds to the JSON property file



1480
1481
1482
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1480

def file
  @file
end

#pathString

Required. The absolute path of the file within the VM. Corresponds to the JSON property path

Returns:

  • (String)


1485
1486
1487
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1485

def path
  @path
end

#permissionsString

Consists of three octal digits which represent, in order, the permissions of the owner, group, and other users for the file (similarly to the numeric mode used in the linux chmod utility). Each digit represents a three bit number with the 4 bit corresponding to the read permissions, the 2 bit corresponds to the write bit, and the one bit corresponds to the execute permission. Default behavior is 755. Below are some examples of permissions and their associated values: read, write, and execute: 7 read and execute: 5 read and write: 6 read only: 4 Corresponds to the JSON property permissions

Returns:

  • (String)


1497
1498
1499
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1497

def permissions
  @permissions
end

#stateString

Required. Desired state of the file. Corresponds to the JSON property state

Returns:

  • (String)


1502
1503
1504
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1502

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1509
1510
1511
1512
1513
1514
1515
# File 'lib/google/apis/osconfig_v2/classes.rb', line 1509

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @file = args[:file] if args.key?(:file)
  @path = args[:path] if args.key?(:path)
  @permissions = args[:permissions] if args.key?(:permissions)
  @state = args[:state] if args.key?(:state)
end